﻿using System.Windows.Input;
using System.Windows;

using Microsoft.Xaml.Behaviors;

namespace TestProject
{
    /// <summary>
    /// 마우스 휠 무사 동작
    /// </summary>
    public sealed class IgnoreMouseWheelBehavior : Behavior<UIElement>
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 부착시 처리하기 - OnAttached()

        /// <summary>
        /// 부착시 처리하기
        /// </summary>
        protected override void OnAttached()
        {
            base.OnAttached();

            AssociatedObject.PreviewMouseWheel += AssociatedObject_PreviewMouseWheel;
        }

        #endregion
        #region 탈착시 처리하기 - OnDetaching()

        /// <summary>
        /// 탈착시 처리하기
        /// </summary>
        protected override void OnDetaching()
        {
            AssociatedObject.PreviewMouseWheel -= AssociatedObject_PreviewMouseWheel;

            base.OnDetaching();
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 연관 객체 프리뷰 마우스 휠 처리하기 - AssociatedObject_PreviewMouseWheel(sender, e)

        /// <summary>
        /// 연관 객체 프리뷰 마우스 휠 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void AssociatedObject_PreviewMouseWheel(object sender, MouseWheelEventArgs e)
        {
            e.Handled = true;

            MouseWheelEventArgs mouseWheelEventArgs = new MouseWheelEventArgs(e.MouseDevice, e.Timestamp, e.Delta);

            mouseWheelEventArgs.RoutedEvent = UIElement.MouseWheelEvent;

            AssociatedObject.RaiseEvent(mouseWheelEventArgs);
        }

        #endregion
    }
}